Crate jj_core

Crate jj_core 

The core library powering the Jujutsu Version Control System. It contains all “base” types such as Commit and the Backend trait.

Modules

conflict_labels
Labels for conflicted trees.
content_hash
Portable, stable hashing suitable for identifying values
dag_walk
General-purpose DAG algorithms.
dag_walk_async
General-purpose async DAG algorithms.
diff
file_util
Contains file utilities which work in a cross-platform way.
graph
hex_util
Hex string helpers.
matchers
Contains the Matcher trait which is used for matching against RepoPaths and guiding walks of directory trees.
merge
Generic data structures and algorithms for working with merges and diffs of values.
object_id
Identifiers for objects (commits, changes, trees, etc.), and utilities for parsing and matching identifier prefixes.
ref_name
Name types for commit references.
repo_path
A RepoPath is a path relative to the repo root. It uses forward slashes as directory separators regardless of platform. It is always valid UTF-8.
str_util
String helpers.
symbol_util
Symbol and string formatting and parsing utilities for our DSL.