The core library powering the Jujutsu Version Control System. It contains
all “base” types such as Commit and the Backend trait.
Modules
- conflict_
labels - Labels for conflicted trees.
- content_
hash - Portable, stable hashing suitable for identifying values
- dag_
walk - General-purpose DAG algorithms.
- dag_
walk_ async - General-purpose async DAG algorithms.
- diff
- file_
util - Contains file utilities which work in a cross-platform way.
- graph
- hex_
util - Hex string helpers.
- matchers
- Contains the
Matchertrait which is used for matching againstRepoPaths and guiding walks of directory trees. - merge
- Generic data structures and algorithms for working with merges and diffs of values.
- object_
id - Identifiers for objects (commits, changes, trees, etc.), and utilities for parsing and matching identifier prefixes.
- ref_
name - Name types for commit references.
- repo_
path - A
RepoPathis a path relative to the repo root. It uses forward slashes as directory separators regardless of platform. It is always valid UTF-8. - str_
util - String helpers.
- symbol_
util - Symbol and string formatting and parsing utilities for our DSL.